package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;

/**
 * FileSource
 */
public class FileSource {

    public enum SourceType { BUNDLED, DIRECT, GITHUB, GIT, DOWNLOAD, GENERATED }
    @Nonnull protected final SourceType type;
    @Nonnull protected final String value;
    @Nonnull protected final String basename;

    public FileSource(@Nonnull SourceType type, @Nonnull String value, @Nonnull String basename) {
        this.type = type;
        this.value = value;
        this.basename = basename;
    }

    @Nonnull
    public SourceType getType() {
        return type;
    }

    @Nonnull
    public String getValue() {
        return value;
    }

    @Nonnull
    public String getBasename() {
        return basename;
    }

    /**
     * conveniance method that returns true for type GENERATE and value KEYPAIR*
     * @return
     */
    public boolean isGeneratedKeyPair() {
        return type == FileSource.SourceType.GENERATED &&
                value.trim().toLowerCase().startsWith("keypair");
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof FileSource)) return false;

        FileSource source = (FileSource) o;

        if (type != source.type) return false;
        if (!value.equals(source.value)) return false;
        return basename.equals(source.basename);
    }

    @Override
    public int hashCode() {
        int result = type.hashCode();
        result = 31 * result + value.hashCode();
        result = 31 * result + basename.hashCode();
        return result;
    }

    @Override
    public String toString() {
        return "FileSource(" +
                "" + type + "" +
                " \"" + value + "\"" +
                " (\"" + basename + "\")" +
                ')';
    }
}
